@@ -19,13 +19,13 @@
 # REQUIREMENTS
 # Requires python and the following dependencies (all pip/easy_installable):
 #
-# elasticsearch (official Elasticsearch Python API, 
+# elasticsearch (official Elasticsearch Python API,
 # http://www.elasticsearch.org/guide/en/elasticsearch/client/python-api/current/index.html)
 #
 # argparse (built-in in python2.7 and higher, python 2.6 and lower will have to
 # easy_install it)
 #
-# TODO: Unit tests. The code is somewhat broken up into logical parts that may 
+# TODO: Unit tests. The code is somewhat broken up into logical parts that may
 #       be tested separately.
 #       Make sure the code can be used outside of __main__ by people importing the module
 #       Better error reporting?
@@ -34,7 +34,6 @@
 import sys
 import time
 import logging
-import argparse
 from datetime import timedelta, datetime
 
 import elasticsearch
@@ -49,24 +48,37 @@ except ImportError:
         def emit(self, record):
             pass
 
-__version__ = '0.6.1'
+__version__ = '0.6.2'
 
+# Elasticsearch versions supported
+version_max  = (1, 0, 0)
+version_min = (0, 19, 4)
+        
 logger = logging.getLogger(__name__)
 
 def make_parser():
     """ Creates an ArgumentParser to parse the command line options. """
-    parser = argparse.ArgumentParser(description='Curator for Elasticsearch indices.  Can delete (by space or time), close, disable bloom filters and optimize (forceMerge) your indices.')
-
-    parser.add_argument('-v', '--version', action='version', version='%(prog)s '+__version__)
-
+    help_desc = 'Curator for Elasticsearch indices.  Can delete (by space or time), close, disable bloom filters and optimize (forceMerge) your indices.'
+    try:
+        import argparse
+        parser = argparse.ArgumentParser(description=help_desc)
+        parser.add_argument('-v', '--version', action='version', version='%(prog)s '+__version__)
+    except ImportError:
+        import optparse
+        parser = optparse.OptionParser(description=help_desc, version='%prog '+ __version__)
+        parser.parse_args_orig = parser.parse_args
+        parser.parse_args = lambda: parser.parse_args_orig()[0]
+        parser.add_argument = parser.add_option
     parser.add_argument('--host', help='Elasticsearch host. Default: localhost', default='localhost')
+    parser.add_argument('--url_prefix', help='Elasticsearch http url prefix. Default: none', default='')
     parser.add_argument('--port', help='Elasticsearch port. Default: 9200', default=9200, type=int)
+    parser.add_argument('--ssl', help='Connect to Elasticsearch through SSL. Default: false', action='store_true', default=False)
     parser.add_argument('-t', '--timeout', help='Elasticsearch timeout. Default: 30', default=30, type=int)
 
     parser.add_argument('-p', '--prefix', help='Prefix for the indices. Indices that do not have this prefix are skipped. Default: logstash-', default='logstash-')
     parser.add_argument('-s', '--separator', help='Time unit separator. Default: .', default='.')
 
-    parser.add_argument('-C', '--curation-style', dest='curation_style', action='store', help='Curate indices by [time, space] Default: time', default='time', type=str)    
+    parser.add_argument('-C', '--curation-style', dest='curation_style', action='store', help='Curate indices by [time, space] Default: time', default='time', type=str)
     parser.add_argument('-T', '--time-unit', dest='time_unit', action='store', help='Unit of time to reckon by: [days, hours] Default: days', default='days', type=str)
 
     parser.add_argument('-d', '--delete', dest='delete_older', action='store', help='Delete indices older than n TIME_UNITs.', type=int)
@@ -91,13 +103,13 @@ def validate_args(myargs):
     if myargs.curation_style == 'time':
         if not myargs.delete_older and not myargs.close_older and not myargs.bloom_older and not myargs.optimize:
             success = False
-            messages.append('Must specify at least one of --delete, --close, --bloom, --optimize')
-        if ((myargs.delete_older and myargs.delete_older < 1) or 
-            (myargs.close_older and myargs.close_older < 1) or 
-            (myargs.bloom_older and myargs.bloom_older < 1) or 
+            messages.append('Must specify at least one of --delete, --close, --bloom or --optimize')
+        if ((myargs.delete_older and myargs.delete_older < 1) or
+            (myargs.close_older and myargs.close_older < 1) or
+            (myargs.bloom_older and myargs.bloom_older < 1) or
             (myargs.optimize and myargs.optimize < 1)):
             success = False
-            messages.append('Values for --delete, --close, --bloom, --optimize must be > 0')
+            messages.append('Values for --delete, --close, --bloom or --optimize must be > 0')
         if myargs.time_unit != 'days' and myargs.time_unit != 'hours':
             success = False
             messages.append('Values for --time-unit must be either "days" or "hours"')
@@ -110,7 +122,7 @@ def validate_args(myargs):
     else: # Curation-style is 'space'
         if (myargs.delete_older or myargs.close_older or myargs.bloom_older or myargs.optimize):
             success = False
-            messages.append('Cannot specify --curation-style "space" and any of --delete, --close, --bloom, --optimize')
+            messages.append('Cannot specify --curation-style "space" and any of --delete, --close, --bloom or --optimize')
         if (myargs.disk_space == 0) or (myargs.disk_space < 0):
             success = False
             messages.append('Value for --disk-space must be greater than 0')
@@ -130,18 +142,21 @@ def get_index_time(index_timestamp, separator='.'):
     except ValueError:
         return datetime.strptime(index_timestamp, separator.join(('%Y', '%m', '%d')))
 
+def get_version(client):
+    """Return ES version number as a tuple"""
+    version = client.info()['version']['number']
+    return tuple(map(int, version.split('.')))
+
 def can_bloom(client):
     """Return True if ES version > 0.90.9"""
-    version = client.info()['version']['number']
-    version_number = tuple(map(int, version.split('.')))
+    version_number = get_version(client)
     # Bloom filter unloading not supported in versions < 0.90.9
     if version_number >= (0, 90, 9):
         return True
     else:
-        logger.warn('Your Elasticsearch version {0} is too old to use the bloom filter disable feature. Requires 0.90.9+'.format(version))
+        logger.warn('Your Elasticsearch version {0} is too old to use the bloom filter disable feature. Requires 0.90.9+'.format(".".join(map(str,version_number))))
         return False
 
-
 def find_expired_indices(client, time_unit, unit_count, separator='.', prefix='logstash-', utc_now=None):
     """ Generator that yields expired indices.
 
@@ -155,7 +170,7 @@ def find_expired_indices(client, time_unit, unit_count, separator='.', prefix='l
     utc_now = utc_now.replace(hour=0, minute=0, second=0, microsecond=0)
 
     cutoff = utc_now - timedelta(**{time_unit: unit_count})
-    required_parts = 4 if time_unit == 'hourly' else 3
+    required_parts = 4 if time_unit == 'hours' else 3
 
     sorted_indices = sorted(client.indices.get_settings().keys())
 
@@ -221,21 +236,13 @@ def find_overusage_indices(client, disk_space_to_keep, separator='.', prefix='lo
 
 def index_closed(client, index_name):
     """Return True if index is closed"""
-    try:
-        # 1.0 params
-        index_metadata = client.cluster.state(
-            index=index_name,
-            metric='metadata',
-        )
-    except TypeError:
-        # 0.90 params:
-        index_metadata = client.cluster.state(
-            filter_blocks=True,
-            filter_index_templates=True,
-            filter_indices=index_name,
-            filter_nodes=True,
-            filter_routing_table=True,
-        )
+    index_metadata = client.cluster.state(
+        filter_blocks=True,
+        filter_index_templates=True,
+        filter_indices=index_name,
+        filter_nodes=True,
+        filter_routing_table=True,
+    )
     return index_metadata['metadata']['indices'][index_name]['state'] == 'close'
 
 def _close_index(client, index_name, **kwargs):
@@ -332,8 +339,14 @@ def main():
         logger.error('Malformed arguments: {0}'.format(';'.join(check_args)))
         parser.print_help()
         return
-
-    client = elasticsearch.Elasticsearch('{0}:{1}'.format(arguments.host, arguments.port), timeout=arguments.timeout)
+    client = elasticsearch.Elasticsearch(host=arguments.host, port=arguments.port, url_prefix=arguments.url_prefix, timeout=arguments.timeout, use_ssl=arguments.ssl)
+    
+    version_number = get_version(client)
+    logger.debug('Detected Elasticsearch version {0}'.format(".".join(map(str,version_number))))
+    if version_number >= version_max or version_number < version_min:
+        print('Expected Elasticsearch version range > {0} < {1}'.format(".".join(map(str,version_min)),".".join(map(str,version_max))))
+        print('ERROR: Incompatible with version {0} of Elasticsearch.  Exiting.'.format(".".join(map(str,version_number))))
+        sys.exit(1)
 
     # Delete by space first
     if arguments.disk_space:
